@@ -6,7 +6,7 @@
 tau.empirical <- function(theta, frailty, N=1000) {
   dat <- genfrail(N=N, K=2, theta=theta, frailty=frailty, 
                   censor.distr="none", covar.distr="none",
-                  Lambda_0_inv=function(t, tau=4.6, C=0.01) (t^(1/tau))/C)
+                  Lambda_0_inv=function(t, c=0.01, d=4.6) (t^(1/d))/c)
   xy <- matrix(dat$time, ncol=2, byrow=TRUE)
   cor(xy[,1], xy[,2], method="kendall")
 }
@@ -19,7 +19,7 @@ tau.numerical <- function(theta, frailty) {
   }), 0, Inf)$value - 1
 }
 
-# Numericcaly determine theta given Kendall's tau
+# Numerically determine theta given Kendall's tau
 theta.given.tau <- function(tau, frailty) {
   uniroot(function(theta) {
     tau.numerical(theta, frailty) - tau
